@@ -1,25 +1,21 @@
-################################################################################
 ##
-##   R package dynsurv by Wenjie Wang, Ming-Hui Chen, Xiaojing Wang, and Jun Yan
-##   Copyright (C) 2011-2019
+## R package dynsurv by Wenjie Wang, Ming-Hui Chen, Xiaojing Wang, and Jun Yan
+## Copyright (C) 2011-2020
 ##
-##   This file is part of the R package dynsurv.
+## This file is part of the R package dynsurv.
 ##
-##   The R package dynsurv is free software: You can redistribute it and/or
-##   modify it under the terms of the GNU General Public License as published
-##   by the Free Software Foundation, either version 3 of the License, or
-##   any later version (at your option). See the GNU General Public License
-##   at <http://www.gnu.org/licenses/> for details.
+## The R package dynsurv is free software: You can redistribute it and/or
+## modify it under the terms of the GNU General Public License as published by
+## the Free Software Foundation, either version 3 of the License, or any later
+## version (at your option). See the GNU General Public License at
+## <https://www.gnu.org/licenses/> for details.
 ##
-##   The R package dynsurv is distributed in the hope that it will be useful,
-##   but WITHOUT ANY WARRANTY without even the implied warranty of
-##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+## The R package dynsurv is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 ##
-################################################################################
 
 
-
-### Plot coefficient data frame ================================================
 ##' Plot Coefficient Function
 ##'
 ##' Plot coefficient values formatted in a data frame returned by function
@@ -51,8 +47,8 @@
 ##' facet_grid ylab theme
 ##' @importFrom grid unit
 ##' @export
-plotCoef <- function(object, smooth = FALSE, ...) {
-
+plotCoef <- function(object, smooth = FALSE, ...)
+{
     p <- ggplot(data = object, aes_string(x = "Time"))
 
     if (!smooth)
@@ -64,7 +60,7 @@ plotCoef <- function(object, smooth = FALSE, ...) {
             geom_line(aes_string(y = "High"), linetype = 2) +
             geom_line(aes_string(y = "Low"), linetype = 2)
 
-    if (length(levels(factor(object$Model))) == 1)
+    if (length(unique(object$Model)) == 1)
         p <- p + facet_wrap(~ Cov, scales = "free_y")
     else
         p <- p + facet_grid(Cov ~ Model, scales = "free_y")
@@ -76,8 +72,6 @@ plotCoef <- function(object, smooth = FALSE, ...) {
 }
 
 
-
-### Plot iteration jump data frame returned by jump.bayesCox ===================
 ##' Plot Jump Information in Bayesian Dynamic Model
 ##'
 ##' \code{plotJumpTrace} plots the MCMC history of the number of pieces.
@@ -101,13 +95,13 @@ NULL
 ##' @importFrom ggplot2 ggplot aes_string geom_line facet_wrap xlab ylab theme
 ##' @importFrom grid unit
 ##' @export
-plotJumpTrace <- function(object, ...) {
-    p <- ggplot(data = object, aes_string(x = "Iter", y = "Count")) +
+plotJumpTrace <- function(object, ...)
+{
+    ggplot(data = object, aes_string(x = "Iter", y = "Count")) +
         geom_line(size = 0.1, alpha = 0.6) +
         facet_wrap(~ Cov) +
         xlab("Iteration") + ylab("Pieces of Coefficient") +
         theme(plot.margin = unit(rep(0, 4), "lines"))
-    p
 }
 
 
@@ -117,20 +111,19 @@ plotJumpTrace <- function(object, ...) {
 ##' @importFrom ggplot2 ggplot aes_string stat_bin facet_wrap xlab ylab theme
 ##' @importFrom grid unit
 ##' @export
-plotJumpHist <- function(object, ...) {
+plotJumpHist <- function(object, ...)
+{
     ## p <- ggplot(data = object, aes(x = factor(Count))) +
-    p <- ggplot(data = object, aes_string(x = "Count")) +
-        ##   stat_bin(aes(y  = ..count../sum(..count..))) +
+    ggplot(data = object, aes_string(x = "Count")) +
+        ## stat_bin(aes(y  = ..count../sum(..count..))) +
         stat_bin(aes_string(y  =  "..density..")) +
         facet_wrap(~ Cov) +
-        xlab("Pieces of Coefficient") + ylab("Relative Frequency") +
+        xlab("Pieces of Coefficient") +
+        ylab("Relative Frequency") +
         theme(plot.margin = unit(rep(0, 4), "lines"))
-    p
 }
 
 
-
-### Plot the latent variance nu from the bayesCox model ========================
 ##' Plot Latent Variance in Bayesian Cox Model
 ##'
 ##' Plot the latent variance \code{nu} when the hierarchical AR(1) process
@@ -152,7 +145,8 @@ plotJumpHist <- function(object, ...) {
 ##' facet_grid
 ##' @importFrom grid unit
 ##' @export
-plotNu <- function(object, ...) {
+plotNu <- function(object, ...)
+{
     cnt <- "..density.."
     ## p <- ggplot(data = object, aes_string(x = "Value")) +
     p <- ggplot(data = object, aes_string(x = "Value")) +
