@@ -1,42 +1,24 @@
-################################################################################
 ##
-##   R package dynsurv by Wenjie Wang, Ming-Hui Chen, Xiaojing Wang, and Jun Yan
-##   Copyright (C) 2011-2019
+## R package dynsurv by Wenjie Wang, Ming-Hui Chen, Xiaojing Wang, and Jun Yan
+## Copyright (C) 2011-2020
 ##
-##   This file is part of the R package dynsurv.
+## This file is part of the R package dynsurv.
 ##
-##   The R package dynsurv is free software: You can redistribute it and/or
-##   modify it under the terms of the GNU General Public License as published
-##   by the Free Software Foundation, either version 3 of the License, or
-##   any later version (at your option). See the GNU General Public License
-##   at <http://www.gnu.org/licenses/> for details.
+## The R package dynsurv is free software: You can redistribute it and/or
+## modify it under the terms of the GNU General Public License as published by
+## the Free Software Foundation, either version 3 of the License, or any later
+## version (at your option). See the GNU General Public License at
+## <https://www.gnu.org/licenses/> for details.
 ##
-##   The R package dynsurv is distributed in the hope that it will be useful,
-##   but WITHOUT ANY WARRANTY without even the implied warranty of
-##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+## The R package dynsurv is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 ##
-################################################################################
 
 
-
-## ##' Print an object.
-## ##'
-## ##' An S3 class generic function that displays certain object.
-## ##'
-## ##' For \code{bayesCox} (\code{tvTran}, or \code{splineCox}) object,
-## ##' it prints out the brief summary of the fitted model.
-## ##'
-## ##' @param x An object used to dispatch a method.
-## ##' @param ... Other arguments.
-
-
-
-### Print bayesCox object ======================================================
-## ## ' @rdname print
-## ## ' @aliases print.bayesCox
 ##' @export
-print.bayesCox <- function(x, ...) {
-
+print.bayesCox <- function(x, ...)
+{
     cat("\nCall:\n")
     dput(x$call)
 
@@ -60,7 +42,7 @@ print.bayesCox <- function(x, ...) {
         beta <- outer(rep(1, x$K), x$est$beta)
 
     cat("\nBayesian point estimates:\n")
-    est <- data.frame(paste0("(", c(0, head(x$grid, -1)), ", ",
+    est <- data.frame(paste0("(", c(0, x$grid[- length(x$grid)]), ", ",
                              x$grid, "]"),
                       cbind(log(x$est$lambda), beta, x$est$jump))
     estNames <- c("interval", "logLambda",
@@ -73,12 +55,11 @@ print.bayesCox <- function(x, ...) {
 
     cat("\nBayesian measures of model fitting:\n")
     print(data.frame(x$measure), row.names = FALSE)
+    ## return x invisibly
+    invisible(x)
 }
 
 
-### Print tvTran object ========================================================
-## ##' @rdname print
-## ##' @aliases print.tvTran
 ##' @export
 print.tvTran <- function(x, ...) {
 
@@ -89,18 +70,17 @@ print.tvTran <- function(x, ...) {
     print(data.frame(x$control), row.names = FALSE)
 
     cat("\nCoefficient estimates:\n")
-    est <- data.frame(paste0("(", c(0, head(x$eTime, -1)), ", ",
+    est <- data.frame(paste0("(", c(0, x$eTime[- length(x$eTime)]), ", ",
                              x$eTime, "]"),
-                      matrix(x$pEst[seq(1, x$nBeta * x$K)], nrow = x$K))
+                      matrix(x$pEst[seq_len(x$nBeta * x$K)], nrow = x$K))
 
     colnames(est) <- c("interval", x$cov.names)
     print(est, digits = max(options()$digits - 4, 3))
+    ## return x invisibly
+    invisible(x)
 }
 
 
-### Print splineCox object =====================================================
-## ##' @rdname print
-## ##' @aliases print.splineCox
 ##' @export
 print.splineCox <- function(x, ...) {
 
@@ -113,4 +93,6 @@ print.splineCox <- function(x, ...) {
     cat("\nFit results for the expanded data returned by coxph:\n")
     print(x$coxph.fit)
     cat("\n")
+    ## return x invisibly
+    invisible(x)
 }
